@@ -419,7 +419,7 @@ help_contents (GSimpleAction *action,
   if (!uri)
     return;
 
-  url = g_strconcat ("ghelp://", uri, NULL);
+  url = g_strconcat ("help:", uri, NULL);
   open_url (GTK_WINDOW (window), url, gtk_get_current_event_time ());
   g_free (uri);
   g_free (url);
